.. include:: ../README.rst

Example Usage
=============
.. toctree::
   :maxdepth: 2
   
.. toctree::
   :caption: Introduction
   :hidden:

   Adding-Doubling-Basics

   sample
   
.. toctree::
   :caption: NIST Spectra
   :hidden:

   nist

.. toctree::
   :caption: Integrating Spheres
   :hidden:

   sphere-basics
   
   sphere-single
   
   sphere-double
   
   impossible

.. toctree::
   :caption: Adding-Doubling Details
   :hidden:

   quadrature-examples
   
   redistribution
   
   thin-layer
   
.. toctree::
   :caption: API
   :hidden:

   iadpython

.. toctree::
   :caption: Versions
   :hidden:

   changelog
